#!/bin/bash

# Gestore dei Plugin Esterni.

# Version 10/11/2012
# $Revision: 1.16 $
# By UDA'Software 2011

######################################################################
function get_package_info() {
    package_name="${1}"
    
    external_plugin_db_path="$HOME/.xchat2/buduscript"
    external_plugin_db_name="buduscript_script__external_plugin.dat"
    external_plugin_db_url="http://digilander.libero.it/udasoft/Software/Linux/buduscript/buduscript_script__external_plugin.dat"
    
    if [ ! -f "${external_plugin_db_path}/${external_plugin_db_name}" ]; then
	external_plugin_db_timestamp=0
    else
	external_plugin_db_timestamp=$(stat --format=%Y "${external_plugin_db_path}/${external_plugin_db_name}")
    fi
    
    if [ $((${current_timestamp:-86401} - ${external_plugin_db_timestamp:-0})) -gt 86400 ]; then
	printf '/ECHO [EXTERNAL PLUGIN]\t UPDATING DATABASE ...\n'
	[ -f "${external_plugin_db_path}/${external_plugin_db_name}" ] && \
	    mv -f "${external_plugin_db_path}/${external_plugin_db_name}" "${external_plugin_db_path}/${external_plugin_db_name}.old"
	
	wget --timeout=8 --quiet --output-document="${external_plugin_db_path}/${external_plugin_db_name}" "${external_plugin_db_url}"
    fi
    
    if [ -f "${external_plugin_db_path}/${external_plugin_db_name}.old" ]; then
	package_record_old=$(grep -iF "	${package_name}	" "${external_plugin_db_path}/${external_plugin_db_name}.old")
	package_version_old=$(echo "${package_record_old}" | awk -F'\t' '{print $1}')
	package_date_old=$(echo "${package_record_old}" | awk -F'\t' '{print $2}')
    fi
    
    if [ ! -f "${external_plugin_db_path}/${external_plugin_db_name}" ]; then
	printf '/ECHO [EXTERNAL PLUGIN]\t%%B ERRORE FATALE: Impossibile aggiornare il database per il pacchetto %s, devo abortire.\n' "${package_name}"
	exit 1
    fi

    package_record=$(grep -iF "	${package_name}	" "${external_plugin_db_path}/${external_plugin_db_name}")
    package_version=$(echo "${package_record}" | awk -F'\t' '{print $1}')
    package_date=$(echo "${package_record}" | awk -F'\t' '{print $2}')
    package_name=$(echo "${package_record}" | awk -F'\t' '{print $3}')
    package_installation_command=$(echo "${package_record}" | awk -F'\t' '{print $4}')
    
    if [ "${package_version_old}" != "" ]; then
	if [ "${package_version_old}" != "${package_version}" ] || \
	    [ "${package_date_old}" != "${package_date}" ]; then
	    printf '/ECHO [EXTERNAL PLUGIN]\t%%B%%C3,1AGGIORNAMENTO DEL PACCHETTO %s NECESSARIO; DALLA VERSIONE %s DEL %s ALLA VERSIONE %s DEL %s\n' "${package_name}" "${package_version_old}" "${package_date_old}" "${package_version}" "${package_date}"
	fi
    fi
}

function print_cancel_alert() {
    cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
%BHai circa 1 minuto di tempo per annullare l'operazione - se lo desideri - 
%Butilizzando il comando di menu:
%BBuDuScRiPt -> Preferenze -> Gestione Plugin\Script Esterni -> Annulla Install...
EOF
    if [ "${package_name}" != "" ]; then
        cat<<EOF | sed 's@^@/ECHO @g'

%BINSTALLAZIONE DI ${package_name} VER. ${package_version} [ ${package_date} ]
EOF
    fi
}

function check_plugin_hardware_compatibility() {
    hardware_type=$(file /sbin/init | awk '{print $3}')
    plugin_list=$(find $HOME/.xchat2 -maxdepth 1 -name '*.so')
    
    if [ "${hardware_type:-NULL}" != "NULL" ]; then
	for plugin in ${plugin_list}; do
	    plugin_type=$(file "${plugin}" | awk '{print $3}')
	    if [ "${plugin_type}" == "link" ]; then
		plugin_link=$(file "${plugin}" | cut -f2- -d'`' | cut -f1 -d\')
		if [ "${plugin_link:0:1}" != "/" ]; then
		    plugin_type=$(file "$HOME/.xchat2/${plugin_link}" | awk '{print $3}')
		else
		    plugin_type=$(file "${plugin_link}" | awk '{print $3}')
		fi
	    fi
	    
	    if [ ${hardware_type:-NULL} != ${plugin_type:-NULL} ]; then
		printf '/TIMER 90 ECHO [EXTERNAL PLUGIN]\t%%B ATTENZIONE: Il plugin "%s" risulta compilato per un sistema a %s mentre l'\''hardware in uso prevede un %s .\n' "$(basename "${plugin}")" ${plugin_type:-NULL} ${hardware_type:-NULL}

		plugin_name="$(basename "${plugin}" | sed 's@\(-x86_64\)\?\.so$@@')"
                if [ -d "$HOME/.xchat2/${plugin_name}_src" ]; then
                    rm -f "${plugin}"
                    printf '/TIMER 90 ECHO [EXTERNAL PLUGIN]\t Plugin eliminato in automatico; lasciata inalterata versione %s.\n' ${hardware_type:-NULL}
                else
                    printf '/TIMER 90 ECHO [EXTERNAL PLUGIN]\t Si consiglia di eliminare il plugin con il comando:%%B /EXEC rm -vf %s\n' "${plugin}"
                fi
	    fi
	done
    else
	printf '/ECHO [EXTERNAL PLUGIN]\t%%B ATTENZIONE: Impossibile stabilire la tipologia di hardware del sistema; il controllo di compatibilita binaria viene saltato.\n'
    fi
}

function set_menu_type() {
    menu_type="Installa"
    
    if [ "${1:-X}" != "X" ]; then
	if [ "${1: -1}" == "/" ]; then
	    if [ -d "${1}" ]; then
		menu_type="Aggiorna"
		flag_package_installed=1
	    fi
	else
	    if [ -f "${1}" ]; then
		menu_type="Aggiorna"
		flag_package_installed=1
	    fi
	fi
    fi
}

######################################################################
current_timestamp=$(date +%s)
script_path="$(dirname $0)"
command_type=${1}
sub_command_type=${2}
[ "${command_type}" == "" ] && exit 1;

if [ ! $(which wget 2> /dev/null) ]; then
    printf '/ECHO [EXTERNAL PLUGIN]\t%%B ATTENZIONE: "wget" non installato, impossibile gestire installazione e aggiornamenti.\n'
    exit 1;
fi

[ "$(echo "${script_path}" | grep -iF '.xchat/')" != "" ] && exit 1;

######################################################################
case ${command_type} in
    MAKE_MENU)
	check_plugin_hardware_compatibility
	
	cat<<EOF
/MENU -i.xchat2/buduscript/Icons/close_window_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Annulla Installazione in Esecuzione" "budus cmd /ECHO Annullo eventuali procedure di installazione/aggiornamento/rimozione in esecuzione\;/TIMER -quiet -delete 1000\;/TIMER -quiet -delete 1001\;/TIMER -quiet -delete 1002\;/TIMER -quiet -delete 1003\;/TIMER -quiet -delete 1004\;/TIMER -quiet -delete 1005\;/TIMER -quiet -delete 1006\;/TIMER -quiet -delete 1007\;/TIMER -quiet -delete 1008\;/TIMER -quiet -delete 1009"
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/-"
EOF
	if [ "${sub_command_type}" != "BOT" ]; then
	    set_menu_type "$HOME/.xchat2/buduscript_setup/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Setup Grafico" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_GRAPHICS_SETUP"
EOF
	    set_menu_type "$HOME/.xchat2/maxquery_src/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} MaxQuery (Massime Query contemporanee prima di rifiuto automatico)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_MAXQUERY"
EOF
	    set_menu_type "$HOME/.xchat2/ignorelist_src/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} IgnoreLIST (Rapporto dettagliato sugli Utenti Ignorati)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_IGNORELIST"
EOF
	    set_menu_type "$HOME/.xchat2/removecolors_src/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} RemoveColors (Rimuove i colori - Inutile se si usa il FILTRO BuDuScRiPt)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_REMOVECOLORS"
EOF
	    set_menu_type "$HOME/.xchat2/autoaway_src/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} AutoAway (Commuta in AWAY automaticamente dopo un periodo di inattivita')" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_AUTOAWAY"
EOF
	    set_menu_type "$HOME/.xchat2/elist_src/"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Elist (Gestione Database Utenti IRC per il riconoscimento automatico)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_ELIST"
EOF
	    set_menu_type "$HOME/.xchat2/buduscript/advanced_menu.mcr"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Advanced Menu (Menu XChat Avanzato - Gestisce tutti i comandi IRC)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_ADVANCED_MENU"
EOF
	    set_menu_type "$HOME/.xchat2/buduscript/bitlbee.mcr"
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Bitlbee Menu (Menu XChat per la gestione di Bitlbee)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BITLBEE_MENU"
EOF
	fi
	
	set_menu_type "$HOME/.xchat2/buduscript/bot.mcr"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} BOT (Trasforma XChat in un IRC BOT)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT"
EOF
	set_menu_type "$HOME/.xchat2/buduscript/README.games"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Giochi BOT" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT_GAME"
EOF
	set_menu_type "$HOME/.xchat2/buduscript/README.stat"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Statistiche BOT" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT_STAT"
EOF
	set_menu_type "$HOME/.xchat2/buduscript/README.botserv"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} BOT XDCC Server" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT_XDCC_SERVER"
EOF
	set_menu_type "$HOME/.xchat2/buduscript/README.meteo"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Meteo BOT" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT_METEO"
EOF
	set_menu_type "$HOME/.xchat2/buduscript/README.oroscopo"
	cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/${menu_type} Oroscopo BOT" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_BOT_OROSCOPO"
EOF
	
	if [ "${sub_command_type}" != "BOT" ]; then
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/-"
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Aggiorna XBSPSE (Plugin di Ricerca XDCC)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh INSTALL_XBSPSE"
EOF
	
	    cat<<EOF
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/-
/MENU -e$(if [ -d "$HOME/.xchat2/buduscript_setup" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi Setup Grafico" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_GRAPHICS_SETUP"
/MENU -e$(if [ -d "$HOME/.xchat2/maxquery_src" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi MaxQuery" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_MAXQUERY"
/MENU -e$(if [ -d "$HOME/.xchat2/ignorelist_src" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi IgnoreLIST" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_IGNORELIST"
/MENU -e$(if [ -d "$HOME/.xchat2/removecolors_src" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi RemoveColors" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_REMOVECOLORS"
/MENU -e$(if [ -d "$HOME/.xchat2/autoaway_src" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi AutoAway" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_AUTOAWAY"
/MENU -e$(if [ -d "$HOME/.xchat2/elist_src" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi Elist" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_ELIST"
/MENU -e$(if [ -f "$HOME/.xchat2/buduscript/README.advanced_menu" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi Advanced Menu" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_ADVANCED_MENU"
/MENU -e$(if [ -f "$HOME/.xchat2/buduscript/README.bitlbee" ]; then echo 1; else echo 0; fi) -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi Bitlbee Menu" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_BITLBEE_MENU"
/MENU ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/-"
/MENU -i.xchat2/buduscript/Icons/del_16.png ADD "BuDuScRiPt/Preferenze/Gestione Plugin\Script Esterni/Rimuovi BuDuScRiPt (ATTENZIONE)" "budus pipe_script_silent $HOME/.xchat2/buduscript/buduscript_script__external_plugin.sh REMOVE_BUDUSCRIPT"
EOF
	fi
	;;
    REMOVE_GRAPHICS_SETUP)
	[ ! -d "$HOME/.xchat2/buduscript_setup" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	printf '/TIMER -refnum 1000 55 EXEC rm -fr $HOME/.xchat2/buduscript_setup\n'
	;;
    INSTALL_GRAPHICS_SETUP)
	get_package_info "BUDUSCRIPT_SETUP"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Il Setup Grafico e' un software che consente di configurare il plugin BuDuScRiPt
attraverso un'interfaccia semplice e dotata di una guida interna.

Il comportamento di BuDuScRiPt e' determinato da una serie di "variabili" che
possiedono un valore di default e uno corrente, determinato dall'utente; il
valore di ogni variabile puo' essere cambiato attraverso l'uso di un apposito e
relativo comando.

Nel setup grafico viene proposto l'elenco dei comandi per cambiare il valore
delle variabili, il nome della relativa variabile, il valore di default e quello
corrente.
Le variabili possono essere di 3 tipologie: booleana, numerica o testuale.
A seconda della tipologia della variabile selezionata (con il click del mouse
sulla relativa linea) si abilita l'opportuna sezione che consente di modificare
il valore.
Nella parte inferiore viene sempre scritta una guida relativa alla variabile che
aiuta l'utente nella scelta.
Sono presenti 4 pulsanti:
- Load from Disk  : Carica la configurazione salvata, sovrascrivendo quella
                    eventualmente modificata.
- Reset to Default: Ripristina tutte le variabili al valore di default.
- Save to Disk    : Salva su disco la configurazione.
- Exit            : Esce dal programma.

N.B.: Per rendere operativa la configurazione eventualmente modificata e salvata
      dal setup grafico e' necessario, in XChat, farla caricare dal plugin con
      il comando: /budus read

In caso di problemi di funzionamento (ex: il setup grafico non si apre) e'
opportuno verificare la compatibilita' binaria con il proprio Sistema Operativo
e Hardware attraverso lo script "check_library.sh" presente nella cartella
$HOME/.xchat2/buduscript_setup

E' possibile aprire il Setup Grafico dal menu di "BuDuScRiPt -> Preferenze"
oppure tramite il comando: /budus macro setup

N.B.: Non e' possibile mantenere sincronizzati i segni di spunta dal menu
      "Preferenze" con i corrispondenti valori delle variabili se non vengono
      modificate dal menu stesso. In altri termini: cambiando la configurazione
      manualmente o con il setup grafico, il menu non sara' piu' sincronizzato
      nella sessione corrente, lo diventera' ri-avviando XChat.
********************************************************************************
Tra qualche istante parte l'installazione del Setup Grafico ...
EOF
	printf '/TIMER -refnum 1000 55 EXEC rm -fr $HOME/.xchat2/buduscript_setup\n'
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_MAXQUERY)
	[ ! -d "$HOME/.xchat2/maxquery_src" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	[ -f $HOME/.xchat2/maxquery.so ] && printf '/TIMER -refnum 1000 50 UNLOAD maxquery.so\n'
	[ -f $HOME/.xchat2/maxquery-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD maxquery-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/maxquery_src $HOME/.xchat2/maxquery.so $HOME/.xchat2/maxquery-x86_64.so\n'
	;;
    INSTALL_MAXQUERY)
	get_package_info "MAXQUERY"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
MaxQuery e' un ADD-ON per XChat che consente all'utente di stabilire il numero
massimo di QUERY, oltre alle quali, deve essere comunicato un messaggio
automatico all'utente che tenta di aprire la conversazione privata in cui viene
informato che l'operazione e' negata.

Chiaramente anche l'utente locale viene informato se una QUERY e' bloccata, in
modo che possa agire di conseguenza (non fare nulla o aprire la QUERY).

Il plugin puo' essere gestito tramite la sintassi:

 /maxquery <max_dialog_num> [message]

dove "max_dialog_num" rappresenta il numero massimo di QUERY (finestre di chat
privata) oltre alle quali scatta il rifiuto e "message" il messaggio che
l'utente rifiutato si vedra' recapitare (se viene omesso il plugin utilizza
quello di default).

Se non si desidera che vengano aperte delle QUERY e' possibile impostare 
"max_dialog_num" al valore 1 e aprire una QUERY con se stessi. Impostando invece
al valore 0 (zero) il plugin e' disabilitato.

Per maggiori informazioni consultare il file: $HOME/.xchat2/maxquery_src/README
********************************************************************************
Tra qualche istante parte l'installazione dell'ADD-ON ...
EOF
	[ -f $HOME/.xchat2/maxquery.so ] && printf '/TIMER -refnum 1000 50 UNLOAD maxquery.so\n'
	[ -f $HOME/.xchat2/maxquery-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD maxquery-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/maxquery_src $HOME/.xchat2/maxquery.so $HOME/.xchat2/maxquery-x86_64.so\n'
	printf '/TIMER -refnum 1003 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_IGNORELIST)
	[ ! -d "$HOME/.xchat2/ignorelist_src" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	[ -f $HOME/.xchat2/ignorelist.so ] && printf '/TIMER -refnum 1000 50 UNLOAD ignorelist.so\n'
	[ -f $HOME/.xchat2/ignorelist-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD ignorelist-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/ignorelist_src $HOME/.xchat2/ignorelist.so $HOME/.xchat2/ignorelist-x86_64.so\n'
	;;
    INSTALL_IGNORELIST)
	get_package_info "IGNORELIST"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Se si utilizza spesso il comando IGNORE (sia manualmente che attraverso
BuDuScRiPt) puo' succedere che, ponendo scarsa attenzione alle maschere di
ignore utilizzate (soprattutto se sono molto generiche), si vada ad ignorare
involontariamente utenti che invece si desidera leggere.

IgnoreList e' un plugin che aiuta l'utente a capire in che modo, le maschere di
ignore attive, vanno a censurare gli utenti di un canale, in modo che l'utente
possa provvedere nel caso in cui ci siano situazioni di IGNORE non previste.

Per ottenere il rapporto usare: /ignorelist

Per maggiori informazioni consultare il file: $HOME/.xchat2/ignorelist_src/README
********************************************************************************
Tra qualche istante parte l'installazione dell'ADD-ON ...
EOF
	[ -f $HOME/.xchat2/ignorelist.so ] && printf '/TIMER -refnum 1000 50 UNLOAD ignorelist.so\n'
	[ -f $HOME/.xchat2/ignorelist-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD ignorelist-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/ignorelist_src $HOME/.xchat2/ignorelist.so $HOME/.xchat2/ignorelist-x86_64.so\n'
	printf '/TIMER -refnum 1003 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_REMOVECOLORS)
	[ ! -d "$HOME/.xchat2/removecolors_src" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	[ -f $HOME/.xchat2/removecolors.so ] && printf '/TIMER -refnum 1000 50 UNLOAD removecolors.so\n'
	[ -f $HOME/.xchat2/removecolors-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD removecolors-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/removecolors_src $HOME/.xchat2/removecolors.so $HOME/.xchat2/removecolors-x86_64.so\n'
	;;
    INSTALL_REMOVECOLORS)
	get_package_info "REMOVECOLORS"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Se il FILTRO di BuDuScRiPt risulta troppo potente ma poco pratico e' possibile
scegliere l'utilizzo del plugin RemoveColors che, come un semplice interruttore
ON/OFF, consente di scegliere se i colori devono essere visualizzati o rimossi
da tutti i canali/finestre.

Per passare da modalita' di rimozione e non usare: /removecolors

Per maggiori informazioni consultare il file: $HOME/.xchat2/removecolors_src/README
********************************************************************************
Tra qualche istante parte l'installazione dell'ADD-ON ...
EOF
	[ -f $HOME/.xchat2/removecolors.so ] && printf '/TIMER -refnum 1000 50 UNLOAD removecolors.so\n'
	[ -f $HOME/.xchat2/removecolors-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD removecolors-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/removecolors_src $HOME/.xchat2/removecolors.so $HOME/.xchat2/removecolors-x86_64.so\n'
	printf '/TIMER -refnum 1003 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_AUTOAWAY)
	[ ! -d "$HOME/.xchat2/autoaway_src" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	[ -f $HOME/.xchat2/autoaway.so ] && printf '/TIMER -refnum 1000 50 UNLOAD autoaway.so\n'
	[ -f $HOME/.xchat2/autoaway-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD autoaway-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/autoaway_src $HOME/.xchat2/autoaway.so $HOME/.xchat2/autoaway-x86_64.so\n'
	;;
    INSTALL_AUTOAWAY)
	get_package_info "AUTOAWAY"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
E' un comodo plugin per configurare in automatico lo stato di AWAY su un Server
IRC dopo un tempo di IDLE prestabilito e configurabile dall'utente.

Oltre che dal menu di BuDuScRiPt, il plugin si puo' utilizzare tramite la
sintassi:

 /autoaway <idle_seconds> [command]

dove "idle_seconds" rappresenta il numero di secondi di inattivita', scaduti i
quali, deve essere eseguito il comando "command", eventualmente specificato; se
non viene specificato "command", il plugin esegue in automatico il comando
"/AWAY AutoAway: I'm busy".

Per default "idle_seconds" e' 900 secondi (15min).

Il plugin e' "multi-server": questo implica che gestisce l'auto-away su Server
IRC diversi (ma sempre con i medesimi parametri, non e' possibile specificare
parametri diversi a seconda del server a cui ci si collega) e decide di
intervenire in base al relativo tempo di IDLE (tempo di inattivita').

Per maggiori informazioni consultare il file: $HOME/.xchat2/autoaway_src/README
********************************************************************************
Tra qualche istante parte l'installazione dell'ADD-ON ...
EOF
	[ -f $HOME/.xchat2/autoaway.so ] && printf '/TIMER -refnum 1000 50 UNLOAD autoaway.so\n'
	[ -f $HOME/.xchat2/autoaway-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD autoaway-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/autoaway_src $HOME/.xchat2/autoaway.so $HOME/.xchat2/autoaway-x86_64.so\n'
	printf '/TIMER -refnum 10003 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_ELIST)
	[ ! -d "$HOME/.xchat2/elist_src" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	[ -f $HOME/.xchat2/elist.so ] && printf '/TIMER -refnum 1000 50 UNLOAD elist.so\n'
	[ -f $HOME/.xchat2/elist-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD elist-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/elist_src $HOME/.xchat2/elist.so $HOME/.xchat2/elist-x86_64.so\n'
	;;
    INSTALL_ELIST)
	get_package_info "ELIST"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
EList e' un'interfaccia grafica con la quale manipolare facilmente il "File dei
Domini" (FdM) di BuDuScRiPt.

Il FdM rappresenta un database con il quale l'utente puo' associare informazioni
agli utenti che frequenta in chat in modo che il plugin, basandosi sul
riconoscimento (anche parziale) del "dominio" o del nickname, possa
visualizzarle al momento opportuno (ad esempio quando l'utente individuato apre
una finestra di comunicazione privata).

Il "dominio" e' un indirizzo, che viene associato ad ogni utente dal Server IRC,
che lo identifica in modo univoco. Per essere precisi e' formato da un
"hostname" (a scelta dell'utente) e un "dominio internet" (dipendente dal
provider utilizzato dall'utente per connettersi ad internet o comunque al Server
IRC) nella forma "hostname@dominio".

Gli utenti, normalmente, sono soliti "mascherarsi" dietro nickname diversi
dimenticando di modificare, in qualche modo, il proprio "dominio"; questo e'
dovuto al fatto che, oltre a non essere una caratteristica particolarmente nota,
comunque presenta lati sia noiosi (cambiare hostname e' tedioso - dipende dal
Client - e quantomeno implica disconnettersi e ri-connettersi al Server IRC) che
problematici (cambiare dominio, normalmente, significa disconnettersi e
ri-connettersi ad internet).
E' tuttavia da sottolineare come:
 - Utenti diversi possano avere medesimo dominio (ad esempio con uso di VHOST)
 - I Server IRC, mascherando il dominio, rendono difficoltoso il riconoscimento
 - Basandosi sulla sola parte successiva alla "@" il riconoscimento e' molto
   blando e fuorviante.
 - Se un utente utilizza un hostname molto comune (ex: quello proposto per
   default da alcuni client IRC) il riconoscimento e' molto blando e fuorviante.
 - Laddove il dominio non sia protetto dal Server IRC e' possibile eseguire
   riconoscimento di tipo "generico", ad esempio per conoscere citta' o zona
   dell'utente.

Ulteriori informazioni direttamente in BuDuScRiPt con: /budus help file_domini

Per maggiori informazioni consultare il file: $HOME/.xchat2/elist_src/README
********************************************************************************
Tra qualche istante parte l'installazione dell'ADD-ON ...
EOF
	[ -f $HOME/.xchat2/elist.so ] && printf '/TIMER -refnum 1000 50 UNLOAD elist.so\n'
	[ -f $HOME/.xchat2/elist-x86_64.so ] && printf '/TIMER -refnum 1001 52 UNLOAD elist-x86_64.so\n'
	printf '/TIMER -refnum 1002 55 EXEC rm -vfr $HOME/.xchat2/elist_src $HOME/.xchat2/elist.so $HOME/.xchat2/elist-x86_64.so\n'
	printf '/TIMER -refnum 1003 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_ADVANCED_MENU)
	[ ! -f "$HOME/.xchat2/buduscript/README.advanced_menu" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	printf '/TIMER -refnum 1000 55 EXEC cd $HOME/.xchat2/buduscript && rm -f advanced_menu.mcr init_advanced_menu.mcr buduscript_script__dccallow_man.sh mirc.ini README.advanced_menu\n'
	printf '/TIMER -refnum 1001 60 MENU DEL "Advanced Menu"\n'
	;;
    INSTALL_ADVANCED_MENU)
	get_package_info "ADVANCED_MENU"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
L'Advanced Menu per BuDuScRiPt e' un file INI in formato mIRC che, importato
attraverso una speciale procedura presente nello script, consente di aggiungere
ad XChat un "Menu Utente" ricco di comodi comandi (in particolare consente la
gestione di tutti i comandi NickServ, ChanServ, MemoServ e cosi' via).

Il menu "Advanced Menu" sara' reso operativo al ri-avvio di XChat, oppure,
subito se l'utente lo carica con il comando: /budus macro advanced_menu
********************************************************************************
Tra qualche istante parte l'importazione del Menu ...
EOF
	printf '/TIMER -refnum 1000 55 EXEC cd $HOME/.xchat2/buduscript && rm -f advanced_menu.mcr init_advanced_menu.mcr buduscript_script__dccallow_man.sh mirc.ini README.advanced_menu\n'
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    REMOVE_BITLBEE_MENU)
	[ ! -f "$HOME/.xchat2/buduscript/README.bitlbee" ] && \
	    printf '/ECHO Il pacchetto non risulta installato.\n' && \
	    exit 1;
	
	print_cancel_alert
	printf '/TIMER -refnum 1000 55 EXEC cd $HOME/.xchat2/buduscript && rm -f bitlbee.mcr bitlbee.ini README.bitlbee\n'
	printf '/TIMER -refnum 1001 60 MENU DEL "Bitlbee"\n'
	;;
    INSTALL_BITLBEE_MENU)
	get_package_info "BITLBEE"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Il menu Bitlbee consente di amministrare, tramite XChat, lo speciale Server IRC
dedicato a "Bitlbee", un software che permette di collegarsi a network di
Instant Messaging diversi (Yahoo, MSN, ecc...).

Il menu "Bitlbee" sara' reso operativo al ri-avvio di XChat, oppure,
subito se l'utente lo carica con il comando: /budus macro bitlbee
********************************************************************************
Tra qualche istante parte l'importazione del Menu ...
EOF
	printf '/TIMER -refnum 1000 55 EXEC cd $HOME/.xchat2/buduscript && rm -f bitlbee.mcr bitlbee.ini README.bitlbee\n'
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT)
	printf '/ECHO [EXTERNAL PLUGIN]\t  * Backup della cartella %s .\n' "${HOME}/.xchat2"
	tar czf ${HOME}/buduscript_update_backup_$(date +%Y%m%d%H%M%S).tar.gz ${HOME}/.xchat2
	
	get_package_info "BOT"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Il BOT per XChat proposto da UDA'Software rappresenta un insieme di MACRO e
Bash Script che vanno fortemente a personalizzare BuDuScRiPt in modo da
trasformarlo in quello che, in gergo IRC, viene chiamato IRC BOT.

  N.B.: QUESTA PERSONALIZZAZIONE E' ESTREMAMENTE PROFONDA E NON SARA' POSSIBILE
        RIMUOVERLA DA BuDuScRiPt. SARA' TUTTAVIA POSSIBILE SCEGLIERE SE USARE
        XCHAT COME CLIENT (CIOE' COME LO SI USA ORA) O COME BOT QUANDO SI LANCIA
        IL CLIENT XCHAT, A PROPRIA DISCREZIONE.

La procedura di installazione del BOT apre una finestra, nella quale, vengono
poste delle domande, tese a reperire le informazioni necessarie per costruire una
configurazione di base perfettamente funzionante.

E' importante rispondere con molta attenzione - prendendosi tutto il tempo
necessario - alle domande perche' da esse dipende il funzionamento del BOT.

Il BOT risulta piuttosto semplice da installare, configurare ed usare, tuttavia,
e' indispensabile che l'utente prenda familiarita' con il suo funzionamento
leggendo la relativa guida: $HOME/.xchat2/buduscript/README.bot
********************************************************************************
Tra qualche istante parte l'installazione del BOT ...
EOF
	[ -f $HOME/.xchat2/buduscript/botoff.mcr ] && \
	    printf '/TIMER 10 ECHO [EXTERNAL PLUGIN]\t%%C8,1%%BATTENZIONE: Potrebbe essere necessario chiudere il BOT se attivo; nel prompt di XChat trovi il comando da usare, premere solo INVIO.\n' && \
	    printf '/budus InsertInBuffer() /BUDUS macro botoff\n'
	
	[ -f $HOME/.xchat2/buduscript/bot_config.base ] && \
	    [ ! -f $HOME/.xchat2/buduscript/bot_config.base.previous ] && \
	    cp -vf "$HOME/.xchat2/buduscript/bot_config.base" "$HOME/.xchat2/buduscript/bot_config.base.previous"
	
	[ -f $HOME/.xchat2/buduscript/budus_setup.base ] && \
	    [ ! -f $HOME/.xchat2/buduscript/budus_setup.base.previous ] && \
	    cp -vf "$HOME/.xchat2/buduscript/budus_setup.base" "$HOME/.xchat2/buduscript/budus_setup.base.previous"
	
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT_GAME)
	[ ! -f $HOME/.xchat2/buduscript/bot.mcr ] && \
	    printf '/ECHO Inutile installare i Giochi per il BOT se quest'\''ultimo non e'\'' installato.\n' && \
	    exit 1;
	
	get_package_info "BOT_GAMES"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
I BOT Games sono un pacchetto di giochi in grado di funzionare con il BOT per
XChat.

Aggiunge al canale il comando '!game' con il quale e' possibile gestire i
giochi (lancio, chiusura, ecc...).

Per rendere operativo il tutto e' indispensabile leggere la relativa
documentazione: $HOME/.xchat2/buduscript/README.games
********************************************************************************
Tra qualche istante parte l'installazione dei Giochi per il BOT ...
EOF
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT_STAT)
	[ ! -f $HOME/.xchat2/buduscript/bot.mcr ] && \
	    printf '/ECHO Inutile installare le Statistiche per il BOT se quest'\''ultimo non e'\'' installato.\n' && \
	    exit 1;
	
	get_package_info "BOT_STAT"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Le statistiche per il BOT consentono di conoscere i dati di affluenza dei canali
da esso amministrati.

Per rendere operativo il tutto e' indispensabile leggere la relativa
documentazione: $HOME/.xchat2/buduscript/README.stat
********************************************************************************
Tra qualche istante parte l'installazione delle Statistiche per il BOT ...
EOF
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT_XDCC_SERVER)
	[ ! -f $HOME/.xchat2/buduscript/bot.mcr ] && \
	    printf '/ECHO Inutile installare l'\''XDCC Server per il BOT se quest'\''ultimo non e'\'' installato.\n' && \
	    exit 1;
	
	get_package_info "BOT_XDCC_SERVER"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Il Server XDCC per il BOT consente di offrire un servizio per il download di
files indicizzati.

Per rendere operativo il tutto e' indispensabile leggere la relativa
documentazione: $HOME/.xchat2/buduscript/README.botserv
********************************************************************************
Tra qualche istante parte l'installazione dell'XDCC Server per il BOT ...
EOF
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT_METEO)
	[ ! -f $HOME/.xchat2/buduscript/bot.mcr ] && \
	    printf '/ECHO Inutile installare il Meteo per il BOT se quest'\''ultimo non e'\'' installato.\n' && \
	    exit 1;
	
	get_package_info "BOT_METEO"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Il Meteo per il BOT consente di offrire un servizio di metereologia nel proprio
canale; viene installata una "TCL per eggdrop" (famoso BOT) opportunamente
modificata per funzionare con BuDuScRiPt.

Per rendere operativo il tutto e' indispensabile leggere la relativa
documentazione: $HOME/.xchat2/buduscript/README.meteo
********************************************************************************
Tra qualche istante parte l'installazione del Servizio Meteo per il BOT ...
EOF
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_BOT_OROSCOPO)
	[ ! -f $HOME/.xchat2/buduscript/bot.mcr ] && \
	    printf '/ECHO Inutile installare l'\''Oroscopo per il BOT se quest'\''ultimo non e'\'' installato.\n' && \
	    exit 1;
	
	get_package_info "BOT_OROSCOPO"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
L'Oroscopo per il BOT consente di offrire un servizio di oroscopo nel proprio
canale; viene installata una "TCL per eggdrop" (famoso BOT) opportunamente
modificata per funzionare con BuDuScRiPt.

Per rendere operativo il tutto e' indispensabile leggere la relativa
documentazione: $HOME/.xchat2/buduscript/README.oroscopo
********************************************************************************
Tra qualche istante parte l'installazione del Servizio Meteo per il BOT ...
EOF
	printf '/TIMER -refnum 1001 60 %s\n' "${package_installation_command}"
	;;
    INSTALL_XBSPSE)
	get_package_info "XBSPSE"
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
Gli XBSPSE (XDCC Bash Script Plugin Search Engine) sono lo strumento utilizzato
dall'XDCC MANAGER per creare il database delle risorse scaricabili.

Puo' succedere che uno o piu' XBSPSE richiedano di essere corretti con una
frequenza decisamente superiore a quella con cui vengono rilasciate versioni
nuove di BuDuScRiPt.

Se si utilizza l'XDCC MANAGER e viene segnalato (ad esempio tramite Twitter o
Forum) che si rende necessario aggiornare il pacchetto degli XBSPSE e' opportuno
utilizzare questo comando, viceversa, e' sostanzialmente inutile.

A seguito dell'aggiornamento degli XBSPSE e' indispensabile utilizzare il 
comando di menu:

XDCC -> Gestione Motori di Ricerca -> Ricarica la lista dei XBSPSE disponibili.

al fine di aggiornare la situazione del menu e valutare se bisogna abilitare
nuovi motori di ricerca XDCC, oppure (scelta consigliata) ri-avviare XChat.
********************************************************************************
Tra qualche istante parte l'aggiornamento degli XBSPSE ...
EOF
	printf '/TIMER -refnum 1001 55 %s\n' "${package_installation_command}"
	printf '/TIMER -refnum 1002 60 %s\n' "EXEC touch ${script_path}/budus_first"
	;;
    REMOVE_BUDUSCRIPT)
	printf '/ECHO [EXTERNAL PLUGIN]\t  * Backup della cartella %s .\n' "${HOME}/.xchat2"
	tar czf ${HOME}/buduscript_update_backup_$(date +%Y%m%d%H%M%S).tar.gz ${HOME}/.xchat2
	
	print_cancel_alert
	cat<<EOF | sed 's@^@/ECHO @g'
********************************************************************************
ATTENZIONE: QUESTO COMANDO RIMUOVE COMPLETAMENTE BUDUSCRIPT, I FILE DI
CONFIGURAZIONE, LE MACRO, LE SENTINELLE E TUTTE LE PERSONALIZZAZIONI CHE SI
INTEGRANO CON ESSO (BOT, MENU AGGIUNTIVI, ECC...).

E' stato fatto un backup della cartella ".xchat2" per offrire la possibilita' di
ripristinare la situazione precedente, oppure, recuperare alcuni file.

Questa procedura NON rimuove i plugin aggiuntivi che non si integrano
completamente con BuDuScRiPt, quindi, e' necessario rimuoverli PRIMA di usare
questa operazione, se effettivamente li si vuole eliminare (e' tuttavia
possibile continuare ad usarli senza lo script).
********************************************************************************
Tra qualche istante parte la rimozione totale di BuDuScRiPt ...
EOF
	printf '/TIMER -refnum 1000 60 UNLOAD budus.so\n'
	printf '/TIMER -refnum 1001 65 EXEC cd $HOME/.xchat2 && rm -f budus.so && rm -fr buduscript\n'
	;;
    *)
	echo "/ECHO %C4,0%BERRORE INTERNO: buduscript_script__external_plugin.sh :%C8,1 Comando non previsto."
	;;
esac

######################################################################
